@@ -46,7 +46,6 @@
 #include <Lum/Space.h>
 #include <Lum/Table.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 #include "Configuration.h"
 #include "Package.h"
@@ -84,54 +83,35 @@ public:
   {
     rateAction->Disable();
 
-    AttachModel(packageListTask.GetFinishedAction());
-    AttachModel(uploadTask.GetFinishedAction());
+    Observe(packageListTask.GetFinishedAction());
+    Observe(uploadTask.GetFinishedAction());
 
-    AttachModel(GetOpenedAction());
-    AttachModel(GetClosedAction());
+    Observe(GetOpenedAction());
+    Observe(GetClosedAction());
 
-    AttachModel(selection);
+    Observe(selection);
 
-    AttachModel(rateAction);
-    AttachModel(uploadAction);
-    AttachModel(aboutAction);
+    Observe(rateAction);
+    Observe(uploadAction);
+    Observe(aboutAction);
 
     DetectOssoVersion();
   }
 
-  ~MainDialog()
-  {
-    UnattachModel(aboutAction);
-    UnattachModel(uploadAction);
-    UnattachModel(rateAction);
-
-    UnattachModel(selection);
-
-    UnattachModel(GetClosedAction());
-    UnattachModel(GetOpenedAction());
-
-    UnattachModel(uploadTask.GetFinishedAction());
-    UnattachModel(packageListTask.GetFinishedAction());
-  }
-
-  virtual void PreInit()
+  void PreInit()
   {
     Lum::Button           *button;
     Lum::Panel            *hpanel,*vpanel;
     Lum::Table            *table;
     Lum::Text             *text;
-    Lum::WindowGroup      *wGroup;
     Lum::Model::HeaderRef headerModel;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-
     hpanel=new Lum::HPanel();
     hpanel->SetFlex(true,true);
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Package",Lum::Base::Size::stdCharWidth,10,true);
-    headerModel->AddColumn(L"Rating",Lum::Base::Size::modePixel,100);
+    headerModel->AddColumn(L"Rating",Lum::Base::Size::pixel,100);
 
     table=new Lum::Table();
     table->SetFlex(true,true);
@@ -169,18 +149,21 @@ public:
     text->SetText(ossoVersion,Lum::OS::Font::bold,Lum::Text::centered);
     vpanel->Add(text);
 
-    vpanel->Add(new Lum::VSpace(true));
-
-    button=new Lum::Button(L"_About");
-    button->SetFlex(true,false);
-    button->SetModel(aboutAction);
-    vpanel->Add(button);
-
     hpanel->Add(vpanel);
 
-    wGroup->SetMain(hpanel);
+    SetMain(hpanel);
 
-    SetTop(wGroup);
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
+
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+
+    SetMenu(menu);
 
     packageListTask.SetParent(this);
     packageListTask.SetCaption(L"Reading package list...");
