@@ -31,7 +31,6 @@
 #include <Lum/Space.h>
 #include <Lum/Text.h>
 #include <Lum/View.h>
-#include <Lum/WindowGroup.h>
 
 #include "Globals.h"
 #include <iostream>
@@ -44,9 +43,9 @@ RateDialog::RateDialog(Rating &rating)
 {
   commitAction->Disable();
 
-  AttachModel(comment);
-  AttachModel(commitAction);
-  AttachModel(GetClosedAction());
+  Observe(comment);
+  Observe(commitAction);
+  Observe(GetClosedAction());
 
   comment->SetText(rating.comment);
   if (rating.score>=0) {
@@ -54,13 +53,6 @@ RateDialog::RateDialog(Rating &rating)
   }
 }
 
-RateDialog::~RateDialog()
-{
-  UnattachModel(GetClosedAction());
-  UnattachModel(commitAction);
-  UnattachModel(comment);
-}
-
 void RateDialog::PreInit()
 {
   Lum::Button              *button;
@@ -72,10 +64,6 @@ void RateDialog::PreInit()
   Lum::Panel               *vert;
   Lum::Text                *text;
   Lum::View                *view;
-  Lum::WindowGroup         *wGroup;
-
-  wGroup=new Lum::WindowGroup();
-  wGroup->SetFlex(true,true);
 
   vert=new Lum::VPanel();
 
@@ -130,7 +118,7 @@ void RateDialog::PreInit()
 
   combo=new Lum::IndexCombo();
   //combo->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
-  combo->SetMinWidth(Lum::Base::Size::modePixel,120);
+  combo->SetMinWidth(Lum::Base::Size::pixel,120);
   combo->SetModel(score);
   combo->SetTableModel(rates);
   label->AddLabel(L"Rate:",combo);
@@ -140,7 +128,7 @@ void RateDialog::PreInit()
 
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
-  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
+  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,35);
   edit->SetMinHeight(Lum::Base::Size::stdCharWidth,5);
   edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
   edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
@@ -173,9 +161,7 @@ void RateDialog::PreInit()
 
   vert->Add(row);
 
-  wGroup->SetMain(vert);
-
-  SetTop(wGroup);
+  SetMain(vert);
 
   Dialog::PreInit();
 }
